@@ -4,10 +4,6 @@
 
 import requests
 import logging
-try:
-    from collections.abc import namedtuple
-except ImportError:
-    from collections import namedtuple
 
 ###############################################################################
 # Global Constants And Variables
@@ -19,6 +15,7 @@ log = logging.getLogger(__name__)
 # Utility Classes
 ###############################################################################
 
+
 class InsistentRequest(requests.Session):
     """Make an auto-retrying request that handles connection loss."""
 
@@ -27,47 +24,46 @@ class InsistentRequest(requests.Session):
         self.max_attempts = max_attempts
 
     def __repr__(self):
-        return '{}(max_attempts={})'.format(
-            self.__class__.__name__, self.max_attempts)
+        return "{}(max_attempts={})".format(self.__class__.__name__, self.max_attempts)
 
     def request(self, method, url, **kwargs):
-        logged_kwargs = repr(kwargs) if kwargs else ''
-        log.debug('%s: %s %s', method, url, logged_kwargs)
+        logged_kwargs = repr(kwargs) if kwargs else ""
+        log.debug("%s: %s %s", method, url, logged_kwargs)
 
-        kwargs.setdefault('timeout', 60)
-        kwargs.setdefault('allow_redirects', False)
+        kwargs.setdefault("timeout", 60)
+        kwargs.setdefault("allow_redirects", False)
         for _ in range(self.max_attempts):
             try:
                 resp = super().request(method=method, url=url, **kwargs)
             except (
-                    requests.ConnectionError,
-                    requests.Timeout,
-                    requests.exceptions.ChunkedEncodingError):
+                requests.ConnectionError,
+                requests.Timeout,
+                requests.exceptions.ChunkedEncodingError,
+            ):
                 continue
             return resp
             if 200 <= resp.status_code < 300:
                 return resp
             elif 400 <= resp.status_code < 600:
                 continue
-        raise requests.ConnectionError(
-            'Max retries exceeded with url: {}'.format(url))
+        raise requests.ConnectionError("Max retries exceeded with url: {}".format(url))
 
     def get(self, url, **kwargs):
-        return self.request('GET', url, **kwargs)
+        return self.request("GET", url, **kwargs)
 
     def post(self, url, **kwargs):
-        return self.request('POST', url, **kwargs)
+        return self.request("POST", url, **kwargs)
+
 
 ###############################################################################
 # Exception Classes
 ###############################################################################
 
-class NotFoundException(Exception): pass
+
+class NotFoundException(Exception):
+    pass
+
 
 ###############################################################################
 # Named Tuple Containers
 ###############################################################################
-
-nt = namedtuple
-Activity = nt("Activity", "votes revisions pages lastActive member highestRating totalRating")
-del nt
\ No newline at end of file
